package VMOMI::FileSystemMountInfoVStorageSupportStatus;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
